@@ -14,7 +14,7 @@ import (
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 	kcmdutil "k8s.io/kubectl/pkg/cmd/util"
 	"k8s.io/kubectl/pkg/util/templates"
 	"sigs.k8s.io/yaml"
@@ -35,34 +35,34 @@ import (
 
 var (
 	mirrorLong = templates.LongDesc(`
-			Mirrors the contents of a catalog into a registry.
+		Mirrors the contents of a catalog into a registry.
 
-			This command will pull down an image containing a catalog database, extract it to disk, query it to find
-			all of the images used in the manifests, and then mirror them to a target registry.
+		This command will pull down an image containing a catalog database, extract it to disk, query it to find
+		all of the images used in the manifests, and then mirror them to a target registry.
 
-			By default, the database is extracted to a temporary directory, but can be saved locally via flags.
+		By default, the database is extracted to a temporary directory, but can be saved locally via flags.
 
-			An ImageContentSourcePolicy is written to a file that can be adedd to a cluster with access to the target 
-			registry. This will configure the cluster to pull from the mirrors instead of the locations referenced in
-			the operator manifests.
+		An ImageContentSourcePolicy is written to a file that can be adedd to a cluster with access to the target
+		registry. This will configure the cluster to pull from the mirrors instead of the locations referenced in
+		the operator manifests.
 
-			A mapping.txt file is also created that is compatible with "oc image mirror". This may be used to further
-			customize the mirroring configuration, but should not be needed in normal circumstances.
-		`)
+		A mapping.txt file is also created that is compatible with "oc image mirror". This may be used to further
+		customize the mirroring configuration, but should not be needed in normal circumstances.
+	`)
 	mirrorExample = templates.Examples(`
-# Mirror an operator-registry image and its contents to a registry
-%[1]s quay.io/my/image:latest myregistry.com
+		# Mirror an operator-registry image and its contents to a registry
+		oc adm catalog mirror quay.io/my/image:latest myregistry.com
 
-# Mirror an operator-registry image and its contents to a particular namespace in a registry
-%[1]s quay.io/my/image:latest myregistry.com/my-namespace
+		# Mirror an operator-registry image and its contents to a particular namespace in a registry
+		oc adm catalog mirror quay.io/my/image:latest myregistry.com/my-namespace
 
-# Configure a cluster to use a mirrored registry
-oc apply -f manifests/imageContentSourcePolicy.yaml
+		# Configure a cluster to use a mirrored registry
+		oc apply -f manifests/imageContentSourcePolicy.yaml
 
-# Edit the mirroring mappings and mirror with "oc image mirror" manually
-%[1]s --manifests-only quay.io/my/image:latest myregistry.com
-oc image mirror -f manifests/mapping.txt
-`)
+		# Edit the mirroring mappings and mirror with "oc image mirror" manually
+		oc adm catalog mirror --manifests-only quay.io/my/image:latest myregistry.com
+		oc image mirror -f manifests/mapping.txt
+	`)
 )
 
 const IndexLocationLabelKey = "operators.operatorframework.io.index.database.v1"
@@ -82,6 +82,8 @@ type MirrorCatalogOptions struct {
 	FromFileDir string
 	FileDir     string
 
+	IcspScope string
+
 	SecurityOptions imagemanifest.SecurityOptions
 	FilterOptions   imagemanifest.FilterOptions
 	ParallelOptions imagemanifest.ParallelOptions
@@ -95,6 +97,7 @@ func NewMirrorCatalogOptions(streams genericclioptions.IOStreams) *MirrorCatalog
 		IOStreams:                 streams,
 		IndexImageMirrorerOptions: DefaultImageIndexMirrorerOptions(),
 		ParallelOptions:           imagemanifest.ParallelOptions{MaxPerRegistry: 4},
+		IcspScope:                 "repository",
 	}
 }
 
@@ -105,7 +108,7 @@ func NewMirrorCatalog(f kcmdutil.Factory, streams genericclioptions.IOStreams) *
 		Use:     "mirror SRC DEST",
 		Short:   "mirror an operator-registry catalog",
 		Long:    mirrorLong,
-		Example: fmt.Sprintf(mirrorExample, "oc adm catalog mirror"),
+		Example: mirrorExample,
 		Run: func(cmd *cobra.Command, args []string) {
 			kcmdutil.CheckErr(o.Complete(cmd, args))
 			kcmdutil.CheckErr(o.Validate())
@@ -125,6 +128,7 @@ func NewMirrorCatalog(f kcmdutil.Factory, streams genericclioptions.IOStreams) *
 	flags.StringVar(&o.FileDir, "dir", o.FileDir, "The directory on disk that file:// images will be copied under.")
 	flags.StringVar(&o.FromFileDir, "from-dir", o.FromFileDir, "The directory on disk that file:// images will be read from. Overrides --dir")
 	flags.IntVar(&o.MaxPathComponents, "max-components", 2, "The maximum number of path components allowed in a destination mapping. Example: `quay.io/org/repo` has two path components.")
+	flags.StringVar(&o.IcspScope, "icsp-scope", o.IcspScope, "Scope of registry mirrors in imagecontentsourcepolicy file. Allowed values: repository, registry. Defaults to: repository")
 	return cmd
 }
 
@@ -272,7 +276,7 @@ func (o *MirrorCatalogOptions) Complete(cmd *cobra.Command, args []string) error
 	o.ImageMirrorer = mirrorer
 
 	var extractor DatabaseExtractorFunc = func(from imagesource.TypedImageReference) (string, error) {
-		e := imgextract.NewOptions(o.IOStreams)
+		e := imgextract.NewExtractOptions(o.IOStreams)
 		e.SecurityOptions = o.SecurityOptions
 		e.FilterOptions = o.FilterOptions
 		e.ParallelOptions = o.ParallelOptions
@@ -321,6 +325,7 @@ func (o *MirrorCatalogOptions) Complete(cmd *cobra.Command, args []string) error
 		return "", fmt.Errorf("no database file found in %s", e.Mappings[0].To)
 	}
 	o.DatabaseExtractor = extractor
+
 	return nil
 }
 
@@ -331,6 +336,11 @@ func (o *MirrorCatalogOptions) Validate() error {
 	if o.ManifestDir == "" {
 		return fmt.Errorf("must specify path for manifests")
 	}
+	switch o.IcspScope {
+	case "repository", "registry":
+	default:
+		return fmt.Errorf("invalid icsp-scope %s", o.IcspScope)
+	}
 	return nil
 }
 
@@ -347,10 +357,10 @@ func (o *MirrorCatalogOptions) Run() error {
 		fmt.Fprintf(o.IOStreams.ErrOut, "errors during mirroring. the full contents of the catalog may not have been mirrored: %s\n", err.Error())
 	}
 
-	return WriteManifests(o.IOStreams.Out, o.SourceRef.Ref.Name, o.ManifestDir, mapping)
+	return WriteManifests(o.IOStreams.Out, o.SourceRef.Ref.Name, o.ManifestDir, o.IcspScope, mapping)
 }
 
-func WriteManifests(out io.Writer, name, dir string, mapping map[string]Target) error {
+func WriteManifests(out io.Writer, name, dir, icspScope string, mapping map[string]Target) error {
 	f, err := os.Create(filepath.Join(dir, "mapping.txt"))
 	if err != nil {
 		return err
@@ -365,7 +375,7 @@ func WriteManifests(out io.Writer, name, dir string, mapping map[string]Target)
 		return err
 	}
 
-	icsp, err := generateICSP(out, name, mapping)
+	icsp, err := generateICSP(out, name, icspScope, mapping)
 	if err != nil {
 		return err
 	}
@@ -387,7 +397,7 @@ func writeToMapping(w io.StringWriter, mapping map[string]Target) error {
 	return nil
 }
 
-func generateICSP(out io.Writer, name string, mapping map[string]Target) ([]byte, error) {
+func generateICSP(out io.Writer, name string, icspScope string, mapping map[string]Target) ([]byte, error) {
 	icsp := operatorv1alpha1.ImageContentSourcePolicy{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: operatorv1alpha1.GroupVersion.String(),
@@ -400,6 +410,7 @@ func generateICSP(out io.Writer, name string, mapping map[string]Target) ([]byte
 		},
 	}
 
+	registryMapping := map[string]string{}
 	for k, v := range mapping {
 		if len(v.WithDigest) == 0 {
 			fmt.Fprintf(out, "no digest mapping available for %s, skip writing to ImageContentSourcePolicy\n", k)
@@ -415,9 +426,16 @@ func generateICSP(out io.Writer, name string, mapping map[string]Target) ([]byte
 			fmt.Fprintf(out, "error parsing target reference for %s, skip writing to ImageContentSourcePolicy\n", v)
 			continue
 		}
+		if icspScope == "registry" {
+			registryMapping[fromRef.Ref.Registry] = toRef.Ref.Registry
+		} else {
+			registryMapping[fromRef.Ref.AsRepository().String()] = toRef.Ref.AsRepository().String()
+		}
+	}
+	for key := range registryMapping {
 		icsp.Spec.RepositoryDigestMirrors = append(icsp.Spec.RepositoryDigestMirrors, operatorv1alpha1.RepositoryDigestMirrors{
-			Source:  fromRef.Ref.AsRepository().String(),
-			Mirrors: []string{toRef.Ref.AsRepository().String()},
+			Source:  key,
+			Mirrors: []string{registryMapping[key]},
 		})
 	}
 
