@@ -1,6 +1,7 @@
 package importimage
 
 import (
+	"context"
 	"fmt"
 	"strings"
 
@@ -11,8 +12,8 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
 	"k8s.io/cli-runtime/pkg/printers"
-	kcmdutil "k8s.io/kubernetes/pkg/kubectl/cmd/util"
-	"k8s.io/kubernetes/pkg/kubectl/util/templates"
+	kcmdutil "k8s.io/kubectl/pkg/cmd/util"
+	"k8s.io/kubectl/pkg/util/templates"
 
 	imagev1 "github.com/openshift/api/image/v1"
 	imagev1client "github.com/openshift/client-go/image/clientset/versioned/typed/image/v1"
@@ -38,8 +39,8 @@ var (
 		see the 'tag' command.`)
 
 	importImageExample = templates.Examples(`
-	  %[1]s import-image mystream
-		`)
+		oc import-image mystream
+	`)
 )
 
 // ImageImportOptions contains all the necessary information to perform an import.
@@ -72,7 +73,7 @@ type ImportImageOptions struct {
 	genericclioptions.IOStreams
 }
 
-func NewImportImageOptions(name string, streams genericclioptions.IOStreams) *ImportImageOptions {
+func NewImportImageOptions(streams genericclioptions.IOStreams) *ImportImageOptions {
 	return &ImportImageOptions{
 		PrintFlags:      genericclioptions.NewPrintFlags("imported"),
 		IOStreams:       streams,
@@ -81,14 +82,14 @@ func NewImportImageOptions(name string, streams genericclioptions.IOStreams) *Im
 }
 
 // NewCmdImportImage implements the OpenShift cli import-image command.
-func NewCmdImportImage(fullName string, f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
-	o := NewImportImageOptions(fullName, streams)
+func NewCmdImportImage(f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
+	o := NewImportImageOptions(streams)
 
 	cmd := &cobra.Command{
 		Use:     "import-image IMAGESTREAM[:TAG]",
 		Short:   "Imports images from a container image registry",
 		Long:    importImageLong,
-		Example: fmt.Sprintf(importImageExample, fullName),
+		Example: importImageExample,
 		Run: func(cmd *cobra.Command, args []string) {
 			kcmdutil.CheckErr(o.Complete(f, cmd, args))
 			kcmdutil.CheckErr(o.Validate())
@@ -186,7 +187,7 @@ func (o *ImportImageOptions) Run() error {
 		return err
 	}
 
-	result, err := o.imageClient.ImageStreamImports(isi.Namespace).Create(isi)
+	result, err := o.imageClient.ImageStreamImports(isi.Namespace).Create(context.TODO(), isi, metav1.CreateOptions{})
 	if err != nil {
 		return err
 	}
@@ -274,7 +275,7 @@ func (e importError) Error() string {
 
 func (o *ImportImageOptions) createImageImport() (*imagev1.ImageStream, *imagev1.ImageStreamImport, error) {
 	var isi *imagev1.ImageStreamImport
-	stream, err := o.isClient.Get(o.Name, metav1.GetOptions{})
+	stream, err := o.isClient.Get(context.TODO(), o.Name, metav1.GetOptions{})
 	// no stream, try creating one
 	if err != nil {
 		if !errors.IsNotFound(err) {
